import { isWeixin } from '../util/uni-env';
import { onMounted, ref, watch } from 'vue';
function _await(value, then, direct) {
  if (direct) {
    return then ? then(value) : value;
  }
  if (!value || !value.then) {
    value = Promise.resolve(value);
  }
  return then ? value.then(then) : value;
}
function _async(f) {
  return function () {
    for (var args = [], i = 0; i < arguments.length; i++) {
      args[i] = arguments[i];
    }
    try {
      return Promise.resolve(f.apply(this, args));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}
export function useSystemInfo() {
  var sysInfo = ref();
  onMounted(_async(function () {
    try {
      uni.getSystemInfo({
        success: function success(value) {
          sysInfo.value = value;
        }
      });
    } catch (_unused) {
      sysInfo.value = {
        statusBarHeight: 0
      };
    }
    return _await();
  }));
  return sysInfo;
}
export function useMenuButtonInfo() {
  var menuInfo = ref({
    height: 40,
    width: 0,
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  });
  onMounted(function () {
    if (isWeixin()) {
      menuInfo.value = uni.getMenuButtonBoundingClientRect();
    }
  });
  return menuInfo;
}
export function useNavBarInfo() {
  var def = ref(44);
  var navBarHeight = ref();
  var statusBarHeight = ref();
  var sys = useSystemInfo();
  var menu = useMenuButtonInfo();
  watch([sys, menu], function (_ref) {
    var s = _ref[0],
      m = _ref[1];
    if (isWeixin()) {
      if (m.top && m.height && s != null && s.statusBarHeight) {
        navBarHeight.value = (m.top - s.statusBarHeight) * 2 + m.height + s.statusBarHeight;
      } else {
        navBarHeight.value = 0;
      }
    } else {
      navBarHeight.value = def.value;
    }
    if (s != null && s.statusBarHeight) {
      statusBarHeight.value = s.statusBarHeight;
    }
  });
  return {
    navBarHeight: navBarHeight,
    statusBarHeight: statusBarHeight
  };
}