"use strict";

function _await(value, then, direct) {
  if (direct) {
    return then ? then(value) : value;
  }
  if (!value || !value.then) {
    value = Promise.resolve(value);
  }
  return then ? value.then(then) : value;
}
function _async(f) {
  return function () {
    for (var args = [], i = 0; i < arguments.length; i++) {
      args[i] = arguments[i];
    }
    try {
      return Promise.resolve(f.apply(this, args));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSystemInfo = useSystemInfo;
exports.useMenuButtonInfo = useMenuButtonInfo;
exports.useNavBarInfo = useNavBarInfo;
var uni_env_1 = require("../util/uni-env");
var vue_1 = require("vue");
function useSystemInfo() {
  var sysInfo = (0, vue_1.ref)();
  (0, vue_1.onMounted)(_async(function () {
    try {
      uni.getSystemInfo({
        success: function success(value) {
          sysInfo.value = value;
        }
      });
    } catch (_unused) {
      sysInfo.value = {
        statusBarHeight: 0
      };
    }
    return _await();
  }));
  return sysInfo;
}
function useMenuButtonInfo() {
  var menuInfo = (0, vue_1.ref)({
    height: 40,
    width: 0,
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  });
  (0, vue_1.onMounted)(function () {
    if ((0, uni_env_1.isWeixin)()) {
      menuInfo.value = uni.getMenuButtonBoundingClientRect();
    }
  });
  return menuInfo;
}
function useNavBarInfo() {
  var def = (0, vue_1.ref)(44);
  var navBarHeight = (0, vue_1.ref)();
  var statusBarHeight = (0, vue_1.ref)();
  var sys = useSystemInfo();
  var menu = useMenuButtonInfo();
  (0, vue_1.watch)([sys, menu], function (_ref) {
    var s = _ref[0],
      m = _ref[1];
    if ((0, uni_env_1.isWeixin)()) {
      if (m.top && m.height && s != null && s.statusBarHeight) {
        navBarHeight.value = (m.top - s.statusBarHeight) * 2 + m.height + s.statusBarHeight;
      } else {
        navBarHeight.value = 0;
      }
    } else {
      navBarHeight.value = def.value;
    }
    if (s != null && s.statusBarHeight) {
      statusBarHeight.value = s.statusBarHeight;
    }
  });
  return {
    navBarHeight: navBarHeight,
    statusBarHeight: statusBarHeight
  };
}